export default WMTSCapabilities;
export type WMTSCapabilitiesOptions = import("../../types").WMTSCapabilitiesOptions;
/**
 * @typedef {import("../../types").WMTSCapabilitiesOptions} WMTSCapabilitiesOptions
 */
declare class WMTSCapabilities extends TileImage {
    /**
     * Constructs a WMTS capabilities instance and fetches the WMTS capabilities XML from the provided URL.
     *
     * @param {WMTSCapabilitiesOptions} options - Image tile options including URL, layer, and other properties.
     */
    constructor(options: WMTSCapabilitiesOptions);
    version_: string;
    dimensions_: object;
    layer_: string;
    /**
     * Handles the WMTS capabilities XML response by parsing it and setting up the necessary properties.
     *
     * @param {Document} xml - The XML document containing WMTS capabilities.
     * @param {WMTSCapabilitiesOptions} options - Options for WMTS capabilities.
     */
    handleCapabilitiesResponse(xml: Document, options: WMTSCapabilitiesOptions): void;
    requestEncoding_: import("ol/source/WMTS").RequestEncoding;
    matrixSet_: string;
    style_: string;
    format_: string;
    /**
     * Creates a URL function for WMTS tiles based on a template.
     *
     * @param {String} template - The WMTS URL template.
     */
    createFromWMTSTemplate(template: string): (tileCoord: Array<number>) => string | undefined;
}
import TileImage from "ol/source/TileImage.js";
//# sourceMappingURL=WMTSCapabilities.d.ts.map