/**
 * @typedef {import("../types").AnyLayerWithSource} AnyLayerWithSource
 * @typedef {import("../types").AnyLayer} AnyLayer
 */
/**
 * Retrieves a layer by its ID from the EOxMap instance.
 *
 * @param {import("../main").EOxMap} EOxMap - Instance of the EOxMap class.
 * @param {string} layerId - The ID of the OpenLayers layer to find.
 * @returns {AnyLayerWithSource} - The layer with the specified ID, or `undefined` if it does not exist.
 */
export function getLayerById(EOxMap: import("../main").EOxMap, layerId: string): AnyLayerWithSource;
/**
 * Returns a flat array of all map layers, including nested layers within groups.
 *
 * Note: If you want to get all layers without groups, use the native OpenLayers `getAllLayers` method:
 * https://openlayers.org/en/latest/apidoc/module-ol_Map-Map.html#getAllLayers
 *
 * @param {Array<AnyLayer>} layers - Array of OpenLayers layers, possibly containing groups.
 */
export function getFlatLayersArray(layers: Array<AnyLayer>): import("ol/layer/Base").default[];
export type AnyLayerWithSource = import("../types").AnyLayerWithSource;
export type AnyLayer = import("../types").AnyLayer;
//# sourceMappingURL=layer.d.ts.map