/**
 * This function reads text and attempts to parse it as GeoJSON, KML, or TopoJSON.
 * If successful, it adds the parsed features to the map.
 *
 * @param {string} text - The string containing the geographic data to be parsed.
 * @param {import("ol/layer").Vector} vectorLayer - The vector layer to which the parsed features will be added.
 * @param {import("../main").EOxMap} EOxMap - An instance of EOxMap, used here for context and potentially for further operations like event dispatching.
 * @param {boolean} replaceFeatures - Optional boolean flag indicating whether to replace the existing features with the new ones.
 * @param {Object} parseOptions - Optional object containing options for the parser.
 * @param {boolean} animate - Optional boolean flag indicating whether to animate the map on feature change.
 * @return {void}
 */
export default function parseTextToFeature(text: string, vectorLayer: import("ol/layer").Vector, EOxMap: import("../main").EOxMap, replaceFeatures?: boolean, parseOptions?: any, animate?: boolean): void;
/**
 * Function to check if a string is valid GeoJSON
 *
 * @param {string} text - The string to be checked.
 * @returns {boolean} - `true` if the string is a valid GeoJSON object, `false` otherwise.
 */
export function isGeoJSON(text: string): boolean;
/**
 * Function to check if a string is valid KML
 *
 * @param {string} text - The string to be checked.
 * @returns {boolean} - `true` if the string contains KML tags, `false` otherwise.
 */
export function isKML(text: string): boolean;
/**
 * Function to check if a string is valid TopoJSON
 *
 * @param {string} text - The string to be checked.
 * @returns {boolean} - `true` if the string is a valid TopoJSON object, `false` otherwise.
 */
export function isTopoJSON(text: string): boolean;
//# sourceMappingURL=parse-text.d.ts.map